pub struct Hmtx<'a> {
data: FontData<'a>,
number_of_h_metrics: u16,
}Expand description
The hmtx (Horizontal Metrics) table
Fields
data: FontData<'a>number_of_h_metrics: u16Implementations
Sourceimpl<'a> Hmtx<'a>
impl<'a> Hmtx<'a>
pub const MIN_SIZE: usize = 0
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn h_metrics(&self) -> &'a [LongMetric]
pub fn h_metrics(&self) -> &'a [LongMetric]
Paired advance width/height and left/top side bearing values for each glyph. Records are indexed by glyph ID.
Sourcepub fn left_side_bearings(&self) -> &'a [BigEndian<i16>]
pub fn left_side_bearings(&self) -> &'a [BigEndian<i16>]
Leading (left/top) side bearings for glyph IDs greater than or equal to numberOfLongMetrics.
pub(crate) fn number_of_h_metrics(&self) -> u16
pub fn h_metrics_byte_range(&self) -> Range<usize> ⓘ
pub fn left_side_bearings_byte_range(&self) -> Range<usize> ⓘ